"""Route configuration."""
from typing import Any, Iterable, List

import flask

from flask import Blueprint, current_app, render_template
from flask_pyoidc import OIDCAuthentication
from flask_pyoidc.user_session import UserSession

from frontpage.config import AppConfig, Config, current_config


def _allowed(items_from: Iterable[Any], items_in: Iterable[Any]) -> bool:
    if len(items_from) == 0:
        return True
    for item in items_from:
        if item in items_in:
            return True
    return False


def register(auth: OIDCAuthentication, auth_provider: str) -> Blueprint:
    routes = Blueprint("routes", __name__)

    @routes.route("/")
    @auth.oidc_auth(auth_provider)
    def home():
        """
        Renders the home route.
        """
        user_session = UserSession(flask.session)
        groups: List[str] = user_session.userinfo.get("groups") or []

        config: Config = current_config()
        name = config.core.name
        apps = config.apps
        allowed_apps = {
            ident: a for ident, a in apps.items() if _allowed(a.groups, groups)
        }
        return render_template(
            "home.html", brand_name=name, apps=allowed_apps, groups=groups
        )

    return routes
